# Man pages for pynml command line tools

Use `generate-man-pages` to generate all the man pages.
On Linux systems, these file would go into `/usr/share/man/man1`.
The file can be locally viewed without installation using `man -l pynml.1`.
